@@ -1,6 +1,6 @@
 package Tapper::PRC::Testcontrol;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::PRC::Testcontrol::VERSION = '5.0.1';
+$Tapper::PRC::Testcontrol::VERSION = '5.0.2';
 use 5.010;
 use warnings;
 use strict;
@@ -286,6 +286,7 @@ sub testprogram_execute
                 if ( $retval ) {
                         my $error;
                         sysread($read,$error, $MAXREAD);
+                        $error =~ s/[\r\n]//g;
                         return("Executing $program failed:$error");
                 }
         }
@@ -608,6 +609,9 @@ sub run
         my $config   = $producer->get_local_data("test-prc0");
 
         $self->cfg($config);
+
+        $0 = "tapper-prc-testcontrol-".$self->cfg->{test_run};
+
         $self->cfg->{reboot_counter} = 0 if not defined($self->cfg->{reboot_counter});
 
         if ($self->cfg->{log_to_file}) {
